GiantToadAreaDocument class
An optional sparse-map areas.json document.
Constructors
-
GiantToadAreaDocument({required List<
GiantToadMapArea> areas, Map<String, Object?> additionalFields = const {}}) -
GiantToadAreaDocument.fromJson(Map<
String, Object?> json) -
factory
Properties
-
additionalFields
→ Map<
String, Object?> -
final
-
areas
→ List<
GiantToadMapArea> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
areasAtCell(
int x, int y) → Iterable< GiantToadMapArea> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited