GiantToadCapabilities class

Explicit platform contract used by examples and production fallback paths.

Properties

hashCode int
The hash code for this object.
no setterinherited
kind GiantToadPlatformKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
require(GiantToadCapability capability) → void
status(GiantToadCapability capability) GiantToadCapabilityStatus
supports(GiantToadCapability capability) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited