GiantToadChunkKey class

A stable coordinate key for a sparse tile chunk.

Constructors

GiantToadChunkKey(int x, int y)
const
GiantToadChunkKey.parse(String value)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
final
y int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override