GiantToadDialogue class

Deterministic dialogue graph state independent of its Flutter presentation.

Constructors

GiantToadDialogue({required Iterable<GiantToadDialogueNode> nodes})

Properties

active bool
no setter
choices List<GiantToadDialogueChoice>
no setter
current GiantToadDialogueNode?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance() bool
choose(int index) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(String? nodeId) → void
snapshot() String?
start(String id) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited