GiantToadGridStepper class

Constructors

GiantToadGridStepper({required Vector2 cellSize, Duration duration = const Duration(milliseconds: 150)})

Properties

cellSize → Vector2
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GiantToadGridStepResult
getter/setter pair

Methods

begin({required Rect body, required GiantToadGridDirection direction, required bool isBlocked(Rect destination)}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited
update(double dt) → Vector2

Operators

operator ==(Object other) bool
The equality operator.
inherited