GiantToadScreenFlash class

Time-based screen flash state suitable for a Flame overlay component.

Constructors

GiantToadScreenFlash()

Properties

active bool
no setter
color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
opacity double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trigger(Color color, double duration) → void
update(double dt) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited