GiantToadNativeText class

Text description in authored game coordinates.

Constructors

GiantToadNativeText({required String text, required double x, required double y, required double fontSize, TextStyle? style})
const

Properties

fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
final
text String
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited