GiantToadPixelButton class

A focused, keyboard-activatable pixel-game overlay button.

Inheritance

Constructors

GiantToadPixelButton({required VoidCallback? onPressed, String? label, Widget? child, Key? key, bool autofocus = false, bool selected = false, String? semanticLabel, String? tooltip, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, bool joinLeft = false, bool joinRight = false, bool squareCorners = false, bool compact = false, bool showDepth = true})
const
GiantToadPixelButton.compact({required VoidCallback? onPressed, String? label, Widget? child, Key? key, bool autofocus = false, bool selected = false, String? semanticLabel, String? tooltip, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, bool joinLeft = false, bool joinRight = false, bool squareCorners = false})
const

Properties

autofocus bool
final
child Widget?
final
compact bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
joinLeft bool
final
joinRight bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onFocusChange ValueChanged<bool>?
final
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final
semanticLabel String?
final
showDepth bool
final
squareCorners bool
final
tooltip String?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GiantToadPixelButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited