GiantToadActionMap class
Maps physical control identifiers to semantic game actions.
Constructors
-
GiantToadActionMap(Map<
GiantToadAction, Iterable< bindings)String> > -
GiantToadActionMap.fromJson(Map<
String, Object?> json) -
Decodes persisted bindings keyed by action identifier.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
actionsFor(
String control) → Iterable< GiantToadAction> -
Returns actions activated by
control, such askeyWorgamepadSouth. -
controlsFor(
GiantToadAction action) → Iterable< String> -
isBound(
GiantToadAction action, String control) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Produces stable JSON-compatible bindings keyed by action identifier.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited