GiantToadLavaSurfaceShader class
Reusable Giant Toad runtime shader for animated lava tile surfaces.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- program → FragmentProgram
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required Size size, required double time, double intensity = 1, double speed = 1, Color color = const Color(0xffff5c14)}) → FragmentShader -
draw(
Canvas canvas, Rect bounds, {required double time, double intensity = 1, double speed = 1, Color color = const Color(0xffff5c14), BlendMode blendMode = BlendMode.srcOver}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- asset → const String
- packageAsset → const String