GiantToadScreenFlash class
Time-based screen flash state suitable for a Flame overlay component.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
Color color, double duration) → void -
update(
double dt) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited